API reference
=============

This document provides the API documentation for the DeepPeak package.


.. autoclass:: DeepPeak.machine_learning.classifier.wavenet.WaveNet
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: DeepPeak.machine_learning.classifier.dense.DenseNet
   :members:
   :undoc-members:
   :show-inheritance:

.. autoclass:: DeepPeak.machine_learning.classifier.autoencoder.Autoencoder
   :members:
   :undoc-members:
   :show-inheritance:
